@@ -1,6 +1,6 @@
 package App::Twitch;
 BEGIN {
-  $App::Twitch::VERSION = '0.005';
+  $App::Twitch::VERSION = '0.006';
 }
 # ABSTRACT: Your personal Twitter b...... lalalala
 
@@ -102,6 +102,14 @@ has tmpdir => (
 	documentation => 'Temp directory for the application (default: working directory)',
 );
 
+has ignore_first => (
+	isa => 'Str',
+	is => 'ro',
+	required => 1,
+	default => sub { 1 },
+	documentation => 'When no cache file exist, ignore the first incoming feed news (default: 1)',
+);
+
 #--------------------------------------------------------
 
 has feeds => (
@@ -168,7 +176,7 @@ has twitter => (
 		my $self = shift;
 		$self->logger->debug('Starting Net::Twitter');
 		Net::Twitter->new(
-			traits   => [qw/API::REST API::Search OAuth/],
+			traits   => [qw/ API::REST API::Search OAuth /],
 			consumer_key		=> $self->consumer_key,
 			consumer_secret		=> $self->consumer_secret,
 			access_token		=> $self->access_token,
@@ -210,12 +218,11 @@ event add_feed => sub {
 		my $uri = URI->new($feed_url);
 		my $host = $uri->host;
 		$host =~ s/\./_/g;
-		my $line_number = $self->max_feeds_count - $self->feeds_count;
 		my $feed = {
 			url				=> $feed_url,
-			name			=> $line_number.'_'.$host,
 			delay			=> $self->rss_delay,
 			max_headlines	=> 100,
+			ignore_first	=> $self->ignore_first,
 		};
 		$self->feedaggregator->add_feed($feed);
 	};
@@ -236,7 +243,7 @@ event new_feed_entry => sub {
 sub hashtag_keywords {
 	my ( $self, $text ) = @_;
 	for (@{$self->keywords}) {
-		$text =~ s/(^|\W)($_)/$1\#$2/ig;
+		$text =~ s/(^|[^\w#])($_)/$1#$2/ig;
 	}
 	return $text;
 }
@@ -291,7 +298,7 @@ App::Twitch - Your personal Twitter b...... lalalala
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -325,6 +332,10 @@ L<Net::Twitter>
 
 =item *
 
+L<POE::Component::FeedAggregator>
+
+=item *
+
 L<MooseX::POE>
 
 =back
